\name{coords.aniso}

\alias{coords.aniso}

%- Also NEED an `\alias' for EACH other topic documented here.

\title{(Geometric) anisotropy correction}

\description{
Transforms (or back-transform) coordinates according to the parameters
defining geometric anisotropy.
}
\usage{
coords.aniso(coords, aniso.pars, reverse=FALSE)
}

\arguments{
  \item{coords}{a \eqn{n x 2}{n x 2} matrix with the coordinates to be transformed.}
  \item{aniso.pars}{a vector with two elements: the first should be the
    \emph{anisotropy angle} and the second is the \emph{anisotropy ratio}.
    See DETAILS for the description of these elements.}
  \item{reverse}{Defaults to \code{FALSE}. If \code{TRUE} the reverse
    transformation is performed.}
}

\details{
  \emph{Anisotropy angle} is defined here as the azimuth angle of the
  direction with greater spatial continuity, i.e. the angle between the
  y-axis and the direction with maximum range.

  \emph{Anisotropy ratio} is defined here as the ratio between the ranges
  for the directions with greater and smaller continuity, i.e. the ratio
  between maximum and minimum ranges. It is therefore always
  \eqn{>= 1}{} grater or equal to one.

  If \code{reverse = FALSE} (the default) the
  coordinates are transformed  from the \emph{anisotropic space} to the \emph{isotropic
    space}. The trensformation is done by multiplying the original coordinates by a rotation and a
  shrinking matrix, as follows:
  \deqn{Xm = X \%*\% R \%*\% T}
  where \code{Xm} is a matrix with the modified coordinates (isotropic
  space) , \code{X} is a matrix with original coordinates (anisotropic
  space), \code{R} rotates coordinates according to the anisotropy angle
  and \code{T} shrinks the coordinates according to the anisotropy ratio.
  
  If \code{reverse = TRUE}, the back-transformation is performed:
  \deqn{X = Xm (R T)^{-1}}{X = Xm \%*\% solve( R \%*\% T ).}

}


\value{
  A \eqn{n x 2}{n x 2} matrix with the transformed coordinates.
}

\references{
  Further information about \code{geoR/geoS} can be found at:\cr
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geoR.html}
}

\author{
  Paulo Justiniano Ribeiro Jr. <\email{paulojus@est.ufpr.br}> \cr
  Peter J. Diggle <\email{p.diggle@lancaster.ac.uk}>.
}

%\note{ ~~further notes~~ }

 
%\seealso{ ~~objects to SEE ALSO as \code{\link{~~fun~~}}, ~~~ }

\examples{
par.mf <- par()$mfrow
par(mfrow=c(2,2))
plot(c(-1.5, 1), c(-1, 1), type="n")
text(x=coords.ori[,1], y=coords.ori[,2], lab=1:4)
coords.ori <- matrix(c(0,1,1,0,0,0,1,1), ncol=2)
coordsA <- coords.aniso(coords.ori, c(0, 2))
plot(c(-1.5, 1), c(-1, 1), type="n")
text(x=coordsA[,1], y=coordsA[,2], lab=paste("A", 1:4))
coordsB <- coords.aniso(coords.ori, c(pi/2, 2))
plot(c(-1.5, 1), c(-1, 1), type="n")
text(x=coordsB[,1], y=coordsB[,2], lab=paste("B", 1:4))
coordsC <- coords.aniso(coords.ori, c((3*pi/4), 2))
plot(c(-1.5, 1), c(-1, 1), type="n")
text(x=coordsC[,1], y=coordsC[,2], lab=paste("C", 1:4)) 
par(mfrow=par.mf)
}

\keyword{spatial}
