\name{cov.spatial}

\alias{cov.spatial}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Computes Covariances from Given Distances}

\description{
  Computes the covariances for pairs of points, given their separation distance.
  Includes options for several correlation functions.
  Can be see as a change of metric, from the \emph{euclidian distances} to
  \emph{covariances}.
}

\usage{
cov.spatial(obj, cov.model=c("exponential", "matern", "gaussian",
            "spherical", "circular", "cubic", "wave",
            "powered.exponential", "cauchy", 
            "gneiting", "gneiting.matern", "pure.nugget"),
            cov.pars=stop("no cov.pars argument provived"), kappa)
}
%- maybe also `usage' for other objects documented here.

\arguments{
  \item{obj}{an object (vector or matrix) with distances.}
  \item{cov.model}{a string indicating the type of the correlation
    function.
    See the DETAILS below for options and expressions of the correlation functions.}
  \item{cov.pars}{a vector with 2 elements or a \eqn{ns x 2} matrix with
    the covariance parameters. The first element (if a vector) or first column (if a matrix) is the variance parameter \eqn{\sigma^2}{sigma^2}. The
    second element or column is the correlation function parameter
    \eqn{\phi}{phi}. If a matrix is provided, each row corresponds to
    the parameters of one \emph{spatial structure}. Models with several structures
    are sometimes called \emph{nested models} in the geostatistical literature.}
  \item{kappa}{additional parameter needed for some of the correlation
    functions, namely:\code{"matern", "powered.exponential", "gneiting"} and
    \code{"gneiting.matern"}.}
}


\details{
  The expressions of the covariance functions used here can be found in Ribeiro
  and Diggle (1999). They will be inlcuded here is a (hopefully) near future.
}

\value{
  The function returns covariances values for the given distances.
  The type of object is the same as the type of the object provided in the
  argument \code{obj}, typically a vecotr, matrix or array.
}

\references{
  Ribeiro, P.J. Jr. and Diggle, P.J. (1999) \emph{{\tt geoR/geoS}: a geostatistical package/library for R/S-PLUS}. Tech. Report ST-99-09, Depto
  Maths and Stats, Lancaster University.
  Available at: 
  \url{http://www.maths.lancs.ac.uk/~ribeiro/publications.html}
  

  Further information about \code{geoR/geoS} can be found at:\cr
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geoR.html}
}

\author{
  Paulo J. Ribeiro Jr. <\email{paulojus@est.ufpr.br}> \cr
  Peter J. Diggle <\email{p.diggle@lancaster.ac.uk}>.
}

\note{This is an auxiliary function called by a number of other
  functions in the package.}


\seealso{\code{\link{varcov.spatial}}, \code{\link{likfit}}, \code{\link{krige.bayes}}, \code{\link{krige.conv}}, \code{\link{grf}}. }

\examples{
# Some variogram models with the same pratical range:
xval <- seq(0,1,l=100)
vexp <- cov.spatial(xval, cov.pars=c(1, .2))
vsph <- cov.spatial(xval, cov.pars=c(1, .60), cov.model="sph")
vgau <- cov.spatial(xval, cov.pars=c(1, .60/sqrt(3)), cov.model="gau")
plot(0:1, 0:1, type="n")
lines(xval, (1-vexp))
lines(xval, (1-vsph), lty=2)
lines(xval, (1-vgau), lwd=2)
}


\keyword{spatial}%-- one or more ...





