\name{plot.geodata}

\alias{plot.geodata}

%- Also NEED an `\alias' for EACH other topic documented here.

\title{Exploratory Geostatistical Plots}

\description{
  This function produces a \eqn{2 x 2} graphics display with: plot
  indicating data locations, a 3-D plot with data locations and values
  (or a histogram of the data), two plots of the data against the \emph{X} and
  \emph{Y} coordinates.   
}

\usage{
plot.geodata(geodata, coords=geodata$coords, data=geodata$data,
             trend="cte", lambda=1, col.data=1, window.new=FALSE, ...)
}

%- maybe also `usage' for other objects documented here.

\arguments{
  \item{geodata}{a list containing elements \code{coords} and
    \code{$data} described below. If not provided the arguments
    \code{coords} and \code{data} must be provided instead.}
  \item{coords}{ a \eqn{n x 2} matrix containing in each row Euclidean
    coordinates of the \emph{n} data locations. By default it takes the
    element \code{$coords} of the argument \code{geodata}.}
  \item{data}{a vector with data values. By default it takes the
    element \code{$data} of the argument \code{geodata}.}
  \item{trend}{specifies the mean part of the model. The options are:
    \code{"cte"} (constant mean - default option), \code{"1st"} (a first degree polynomial
    on the coordinates), \code{"2nd"} (a second degree polynomial
    on the coordinates), or a formula of the type \code{~X} where \code{X}
    is a matrix with the covariates (external trend).
    If provided the trend is "removed" and residuals are plotted.}
  \item{lambda}{Box-Cox transformation parameter. Two particular cases
    are \eqn{\lambda = 1}{lambda = 1} which corresponds to no
    transformation and  \eqn{\lambda = 0}{lambda = 0} corresponding to the log-transformation.}
  \item{col.data}{indicates the column of the data to be plotted for the
    cases where more than one data-set is available}
  \item{window.new}{if \code{TRUE} a new graphic device is openned,
    otherwise the current one is used. Defaults to \code{FALSE}.}
  \item{\dots}{further arguments to be passed to the function \code{\link{scatterplot3d}}.}
}

\details{
  By default, this function requires the package
  \emph{scatterplot3d} in order to produce a 3-D plot with data
  locations and coordinates. If this package is not available an
  histogram replaces the 3-D plot.
}

\value{
  A plot is produced on the graphics device. No values returned. 
}

\references{
  Further information about \code{geoR/geoS} can be found at:\cr
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geoR.html}
}

\author{
  Paulo J. Ribeiro Jr. <\email{paulojus@est.ufpr.br}> \cr
  Peter J. Diggle <\email{p.diggle@lancaster.ac.uk}>.
}

%\note{ ~~further notes~~ }

\seealso{\code{\link{points.geodata}}, \code{\link{scatterplot3d}}. }

\examples{
data(s100)
plot(s100)
}

\keyword{spatial}%-- one or more ...
