\name{plot.grf}

\alias{plot.grf}

\title{Plots Variograms for Simulated Data}

\description{
  This function plots variograms for simulated geostatistical data
  generated by the function \code{\link{grf}}. 
}

\usage{
plot.grf(obj, model.line = TRUE, plot.grid = FALSE, ylim = "default", ...)
}


\arguments{
  \item{obj}{an object of the class \code{grf}, typically an output of the function
    \code{\link{grf}}.}
  \item{model.line}{if \code{TRUE} the true variogram model is added to the
    plot with the sample variogram(s)}
  \item{plot.grid}{if \code{TRUE} a plot with data locations is shown}
  \item{ylim}{limits for the y-axis. The default is the maximum value of
    the variogram among all of the simulations }
  \item{\dots}{further arguments to be passed to the functions
    \code{\link{variog}} and \code{\link{plot}}.}
}

\details{
  Plot with sample variogram(s) for simulated data are produced.
  True variogram model used to generate the simulations is shown if
  \code{model = T}. 
  Data locations can be shown if \code{grid = T}.
}

\value{
  A plot with the variogram(s) is produced in the output device. No
  values returned.
}

\references{
  Further information about \code{geoR/geoS} can be found at:\cr
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geoR.html}
}

\author{
  Paulo Justiniano Ribeiro Jr. \email{<paulojus@est.ufpr.br>} \cr
  Peter J. Diggle \email{<p.diggle@lancaster.ac.uk>}
}

%\note{ ~~further notes~~ }

\seealso{\code{\link{grf}}, \code{\link{plot.variogram}},
  \code{\link{variog}}, \code{\link{plot}}.
}


\examples{

par(mfrow=c(2,1))
sim1 <- grf(100, cov.pars=c(10, .25))
# generates simulated data
plot(sim1, grid=T)
# plots the samples locations and the sample variogram with the true model
#
par(mfrow=c(1,1))
sim2 <- grf(100, cov.pars=c(10, .25), nsim=10)
# generates 10 simulated data
plot(sim1)
# plots sample variograms for all simulations with the true model

}

\keyword{spatial, dplot}
