\name{plot.variogram}

\alias{plot.variogram}
%- Also NEED an `\alias' for EACH other topic documented here.

\title{Plot Empirical Variogram}

\description{
  Plots sample (empirical) variogram from an object computed using the
  function \code{\link{variog}}.
}

\usage{
plot.variogram(obj, max.dist=max(obj$u), ylim="default", type="b",
               scaled=F, var.lines=F, envelope.obj=NULL, bin.cloud=F, ...)
}


\arguments{
  \item{obj}{an output from the function \code{\link{variog}}.}
  \item{max.dist}{maximum distance in the x-axis. The default is
    the maximum distance for which the sample variogram was computed.}
  \item{ylim}{limits for the variogram values in the y-axis. The default
    is from 0 to the maximum value in \code{obj$v}.}
  \item{type}{type of line for the empirical variogram. The default is
    \code{"b"} (dots and lines).}
  \item{scaled}{If \code{TRUE} the variogram values are divided by the
    sample variance. This allows comparison between variograms from
    different data and/or variables.}
  \item{var.lines}{If \code{TRUE} a horizontal line is drawn at the value
    of the variance of the data (if \code{scaled = F}) or at 1 (if
    \code{scaled = T}).}
  \item{envelope.obj}{adds a variogram envelope which should have been
    computed previously using the function \code{\link{variog.env}}.}
  \item{bin.cloud}{plots the variogram cloud if the sample variogram
    from \code{\link{variog}} was computed with the option \code{option = "cloud"}.}
  \item{\dots}{other arguments to be passed to the function \code{\link{plot}}.}

}

\details{
  This function allows visualization of sample variogram and
  together with \code{\link{lines.variogram}} can be
  used to compare sample variograms for different data and/or variables.
  Furthermore, together with \code{\link{lines.variomodel}} can be used
  to compare theoretical and/or fitted variogram models against the
  empirical variogram.
}

\value{
  Produces a plot with the variogram on the graphics device.
}

\references{
  Further information about \code{geoR/geoS} can be found at:\cr
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geoR.html}
}


\author{Paulo Justiniano Ribeiro Jr. \email{<paulojus@est.ufpr.br>} \cr
  Peter J. Diggle \email{<p.diggle@lancaster.ac.uk>}
}

%\note{ ~~further notes~~ }
%
% ~Make other sections like WARNING with \section{WARNING }{....} ~
%
\seealso{\code{\link{variog}}, \code{\link{lines.variogram}},
  \code{\link{lines.variomodel}}, \code{\link{variog.env}}, \code{\link{plot.grf}}, \code{\link{plot}}.}

\examples{
sim <- grf(100, cov.pars=c(1, .2))    # generates simulated data
vario <- variog(sim, max.dist=1)      # computes sample variogram
par(mfrow=c(1,2))
plot(vario)                           # plots the sample variogram
plot(vario, scaled=T)                 # plots the scaled sample variogram

}

\keyword{spatial, dplot}
