\name{points.geodata}

\alias{points.geodata}
%- Also NEED an `\alias' for EACH other topic documented here.

\title{Plot with Locations and Data Values}

\description{
  Produce a plot with data locations with options for points sizes,
  patterns and colors being proportional to data values or to its quantiles.
}

\usage{
points.geodata(geodata, coords=geodata$coords, data=geodata$data, data.col=1,
               pt.sizes=c("data.proportional", "rank.proportional",
                          "quintiles", "quartiles", "deciles", "equal"),
               cex.min, cex.max, pch.seq, col.seq, add.to.plot=FALSE,
               round.quantiles=FALSE, graph.pars=FALSE,
               xlab="Coords X", ylab="Coord Y", ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{geodata}{a list containing elements \code{coords} and
    \code{$data} described below. If not provided the arguments
    \code{coords} and \code{data} must be provided instead.}
  \item{coords}{a \eqn{n x 2} matrix containing
    coordinates of the \eqn{n} data locations in each row.
    Defaults to \code{geodata$coords}, if provided.}
  \item{data}{a vector or matrix with data values.
    If a matrix is provided each column is regarded as one variable or realization.
    Defaults to \code{geodata$data}, if provided.}
  \item{data.col}{the number of the data column. Only used for the case when
    \code{$data} is a matrix with several variables or simulations.}
  \item{pt.sizes}{point sizes.}
  \item{cex.min}{minimum values for the graphical parameter
    \code{cex}. Defines the size of the point corresponding the minimum data.}
  \item{cex.max}{maximum values for the graphical parameter \code{cex}. Defines the size of the point corresponding the maximum data.}
  \item{pch.seq}{numbers defining the graphical parameter \code{pch}.}
  \item{col.seq}{number defining the colors in the graphical parameter \code{cor}.}
  \item{add.to.plot}{if \code{TRUE} the points are added to an existing
    plot, otherwise a new plot is created. Defaults to \code{FALSE}.}
  \item{round.quantiles}{whether or not the values of the quantiles
    should be rounded. Defaults to \code{FALSE}.}
  \item{graph.pars}{if \code{TRUE} the graphics parameters are used are
    returned. Defaults to \code{FALSE}.}
  \item{xlab}{X label.}
  \item{ylab}{Y label}
  \item{\dots}{further parameter for the functions \code{\link{points}} or
  \code{\link{plot}}.}
}

%\details{
%
%}

\value{
  A plot is created or added on the current graphics device.
  
  By default no value is returned. However, if \code{graph.pars = TRUE}
  a list with graphical parameters used to produce the plot is returned.
  According to the input the list might contain the following components:

  \item{quantiles}{the values of the quantiles used to divide the data
    (if required).}
  \item{cex}{the values of the graphics expansion parameter \code{cex}.}
  \item{col}{the values of the graphics color parameter \code{col}.}
  \item{pch}{the values of the graphics pattern parameter \code{pch}.}
}

\references{
  Further information about \code{geoR/geoS} can be found at:\cr
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geoR.html}
}

\author{
  Paulo J. Ribeiro Jr. <\email{paulojus@est.ufpr.br}> \cr
  Peter J. Diggle <\email{p.diggle@lancaster.ac.uk}>.
}

%\note{ }

\seealso{\code{\link{plot.geodata}}, \code{\link{points}},
  \code{\link{plot}}, \code{\link{par}}.}

\examples{
data(s100)
points.geodata(s100, xlab="Coord X", ylab="Coord Y")
points.geodata(s100, xlab="Coord X", ylab="Coord Y", col.seq=gray(seq(1,0.2,l=100)), cex.max=3)
points.geodata(s100, pt.sizes="quintile", xlab="Coord X", ylab="Coord Y")
}

\keyword{spatial, dplot, aplot}
%-- one or more ...
