\name{varcov.spatial}

\alias{varcov.spatial}

%- Also NEED an `\alias' for EACH other topic documented here.

\title{Computes Covariance Matrix and/or Related Results}

\description{
  This function computes the covariance matrix for a set of spatial
  locations, for given parameters.
  According to the input other results related to the covariance matrix,
  such as decompositions, determinants, inverse. etc are returned.
}

\usage{
varcov.spatial(coords = NULL, dists.lowertri = NULL,
               cov.model = c("exponential", "matern", "gaussian",
                             "spherical", "circular", "cubic", "wave", 
                             "powered.exponential", "cauchy",
                             "gneiting", "gneiting.matern", "pure.nugget"),
               kappa = NULL, nugget = 0,
               cov.pars = stop("no cov.pars argument"), 
               inv = FALSE, det = FALSE, func.inv = "cholesky",
               scaled = FALSE,  only.decomposition = FALSE,
               sqrt.inv = FALSE, test.decomp = FALSE, 
               only.inv.lower.diag = FALSE) 

}

%- maybe also `usage' for other objects documented here.
\arguments{
  \item{coords}{a \eqn{n x 2} matrix with coordinates. If not provided
    the argument \code{dists.lowertri} should be provided instead.}
  \item{dists.lowertri}{a vector with the lower triangle of the matrix
    of distances between data points. If not provided
    the argument \code{coords} should be provided instead.}
  \item{cov.model}{a string indicating the type of the correlation
    function. See the documentation of \code{\link{cov.spatial}} for the
    options for the correlation function model.}
  \item{kappa}{additional parameter needed for some of the correlation
    functions, namely:\code{"matern", "powered.exponential", "gneiting"} and
    \code{"gneiting.matern"}.}
  \item{nugget}{the value of the nugget parameter.}
  \item{cov.pars}{a vector with 2 elements or a \eqn{ns x 2} matrix with
    the covariance parameters. The first element (if a vector) or first column (if a matrix) is the variance parameter \eqn{\sigma^2}{sigma^2}. The
    second element or column is the correlation function parameter
    \eqn{\phi}{phi}. If a matrix is provided, each row corresponds to
    the parameters of one \emph{spatial structure}. Models with several structures
    are sometimes called \emph{nested models} in the geostatistical literature.}
  \item{inv}{if \code{TRUE} the inverse of covariance
    matrix is returned. Defaults to \code{FALSE}.}
  \item{det}{if \code{TRUE} the  logarithmic of the square root of the
    determinant of the covariance
    matrix is returned. Defaults to \code{FALSE}.}
  \item{func.inv}{algorithm used for the decomposition and inversion of the covariance
    matrix. Options are \code{"chol"} for Choleski decomposition,
    \code{"svd"} for singular value decomposition and \code{"eigen"} for
    eigenvalues/eigenvectors decomposition. Defaults to \code{"chol"}.}
  \item{scaled}{scales the covariance matrix. If \code{TRUE} the sill
    parameter \eqn{\sigma^2}{sigma^2} is set to 1. Defaults to \code{FALSE}.}
  \item{only.decomposition}{if \code{TRUE} only the decomposition is
    returned. Defaults to \code{FALSE}.}
  \item{sqrt.inv}{if \code{TRUE} the square root of the inverse of  covariance
    matrix is returned. Defaults to \code{FALSE}.}
  \item{test.decomp}{}
  \item{only.inv.lower.diag}{if \code{TRUE} only the lower triangle and
    the diagonal of the inverse of the covariance matrix is
    returned. Defaults to \code{FALSE}.}
}


\details{
  The elements of the covariance matrix are computed by the function \code{\link{cov.spatial}}.
}


\value{
  The result is a list. The components will vary according to the input
  options. Possible components of output include:
  
  \item{varcov}{the covariance matrix.}
  \item{sqrt.varcov}{a square root of the covariance matrix.}
  \item{lower.inverse}{the lower triangle of the inverse of covariance matrix.}
  \item{diag.inverse}{the diagonal of the inverse of covariance matrix.}
  \item{inverse}{the inverse of covariance matrix.}
  \item{log.det.to.half}{the logarithmic of the square root of the
    determinant of the covariance matrix.}
  \item{sqrt.inverse}{a square root of the inverse of covariance matrix.}
}

\references{
  Further information about \code{geoR/geoS} can be found at:\cr
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geoR.html}
}

\author{
  Paulo J. Ribeiro Jr. <\email{paulojus@est.ufpr.br}> \cr
  Peter J. Diggle <\email{p.diggle@lancaster.ac.uk}>.
}

%\note{ ~~further notes~~ }

\seealso{\code{\link{cov.spatial}}, \code{\link{chol}},
  \code{\link{svd}}, \code{\link{eigen}}.
}

%\examples{
%}

\keyword{spatial}%-- one or more ...

